@@ -1,6 +1,6 @@
 package Fey::ORM::Schema;
 BEGIN {
-  $Fey::ORM::Schema::VERSION = '0.42';
+  $Fey::ORM::Schema::VERSION = '0.43';
 }
 
 use strict;
@@ -11,12 +11,13 @@ use Fey::Meta::Class::Schema;
 use Fey::Object::Schema;
 
 use Moose 1.15 ();
+use MooseX::StrictConstructor 0.13 ();
 use Moose::Exporter;
 use MooseX::Params::Validate qw( pos_validated_list );
 
 Moose::Exporter->setup_import_methods(
     with_meta => [qw( has_schema )],
-    also      => 'Moose'
+    also      => [ 'Moose', 'MooseX::StrictConstructor' ],
 );
 
 sub init_meta {
@@ -52,7 +53,7 @@ Fey::ORM::Schema - Provides sugar for schema-based classes
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
